//[mahjong-utils](../../../../index.md)/[mahjongutils.models](../../index.md)/[Tatsu](../index.md)/[Companion](index.md)/[invoke](invoke.md)

# invoke

[common]\
operator fun [invoke](invoke.md)(first: [Tile](../../-tile/index.md), second: [Tile](../../-tile/index.md)): [Tatsu](../index.md)

operator fun [invoke](invoke.md)(text: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)): [Tatsu](../index.md)
